@@ -3,6 +3,9 @@
 
 #include <QMainWindow>
 #include <QModelIndex>
+#include <QNetworkAccessManager>
+#include <QTime>
+#include <QFile>
 
 namespace Ui
 {
@@ -18,13 +21,20 @@ public:
     //QAction *newAct2;
     ~MainWindow();
 
-
 private:
     Ui::MainWindow *ui;
+    QNetworkAccessManager manager;
+    QNetworkReply *currentDownload;
+    QTime downloadTime;
+    QFile downfile;
 protected:
     void closeEvent(QCloseEvent *event);
 
 private slots:
+    void appendhostfile(QString filename);
+    void downloadProgress(qint64 bytesReceived, qint64 bytesTotal);
+    void downloadFinished();
+    void downloadReadyRead();
     void save_ini();
     void load_ini();
     void wload_ini();
@@ -154,6 +164,9 @@ private slots:
     void on_pushButton_loadbldomain_clicked();
     void on_pushButton_savebldomain_clicked();
     void on_pushButton_bldnsmasq_restart_clicked();
+    void on_pushButton_loadfile_clicked();
+    void on_pushButton_blhostappend_clicked();
+    void on_pushButton_blhostdown_clicked();
 };
 
 #endif // MAINWINDOW_H
