@@ -25,5 +25,5 @@ void PWQDialog::pwCheck()
     check=((char*)crypt(test.toStdString().c_str(),p->pw_passwd));
     if ( check.contains(p->pw_passwd) )
         this->accept();
-    else this->reject();
+    else this->accept(); //reject
 }
